@@ -1,11 +1,11 @@
-inline std::string const &Options::extension() const
+inline bool Options::all() const
 {
-    return d_required.empty() ? d_internal : d_required;
+    return d_all;
 }
 
-inline std::string const &Options::guard() const
+inline std::string const &Options::extension() const
 {
-    return d_guard;
+    return d_internal;
 }
 
 inline std::string const &Options::classes() const
@@ -33,11 +33,6 @@ inline bool Options::softLink() const
     return d_softLinkOption;
 }
 
-inline bool Options::rh() const
-{
-    return not d_required.empty();
-}
-
 inline bool Options::topDir() const
 {
     return d_topDir;
@@ -53,7 +48,13 @@ inline std::string const &Options::spchGch() const
     return d_spchGch;
 }
 
-inline char const *Options::arg1() const
+inline char const *Options::compilerArg() const
 {
-    return d_arg[1];
+    return d_arg[1 + d_all];
 }
+
+inline std::string const &Options::extraOptions() const
+{
+    return d_extraOptions;
+}
+
